$Title  A Single-Region Shoven-Whalley Model

$Ontext
Model from:
Johannes Broecker
"CGE Analysis"
21st ERSA / 3rd PREPARE Summer Institute
July 6th -- July 15th 2008 in Pecs, Hungary
This code solves the single-region CGE model in the CGE lecuture notes

Adapted to fit our SD microeconomic model -- data see "brcker_2008_MCM.xls"

$Offtext

  Scalar shock shock parameter /1.25/ ;

* Delineate agents:
  Sets
       a    agents                            / firm1, firm2, consumer /
       f(a) firms f(a)=subset of agents       / firm1, firm2 /
       h(a) households h(a)=subset of agents  / consumer /
       i    markets     / good1, good2, labour, capital /
       k(i) markets except capital    / good1, good2, labour / ;

  Alias (i,j) ;

* Put in the data from your MCM:

  Table Pay(i,a)  Payments (alles was im Skript ein negatives Vorzeichen hat)
                     firm1  firm2 consumer
      good1            0      0     14
      good2            0      0      6
      labour          11      2      0
      capital          3      4      0    ;

  Table Rec(i,a)  Receipts (alles was im Skript ein pos. Vorzeichen hat)
                     firm1  firm2 consumer
      good1           14      0      0
      good2            0      6      0
      labour           0      0     13
      capital          0      0      7    ;

* Specify firms' technology:

  Parameters
       sigma(f) Eos of firms
         /    firm1     1.5
              firm2     1.5 / ;

  Parameter alpha(i,f)  input shift-share parameters of firms ;
            alpha(i,f) = (sum(j, Pay(j,f))**(-sigma(f)))*Pay(i,f) ;

  Parameters
       eta(f)   Eot of firms
         /    firm1       0
              firm2       0 / ;

  Parameter beta(i,f)  output shift-share parameters of firms ;
            beta(i,f) = (sum(j, Rec(j,f))**eta(f))*Rec(i,f) ;

* Specify households' preferences and endowments:

  Parameters
       mu(h)  Eos of households
         /    consumer  1.5 / ;

  Parameter gamma(i,h)  consumption shift-share parameter of households ;
            gamma(i,h) = (sum(j, Pay(j,h))**(-mu(h)))*Pay(i,h) ;

  Parameter End(i,h)  Endowments of households ;
            End(i,h) = Rec(i,h) ;

*  The following line simulates the counterfactual situation --> immigration of Joneses!
*  End(i,'Jones')=shock*End(i,'Jones') ;

* Setup your model, declaring your variables first and equations next:

  Variables
       c(f)    unit-cost of firms
       r(f)    unit-revenue of firms
       pi(h)   consumers' price index
       x(f)    firms' activity levels
       u(h)    households' utility
       p(i)    prices ;

  Equations
       cost(f)     firms' unit-cost definition
       reve(f)     firms' unit-revenue definition
       cpi(h)      consumers' price index definition
       zpr(f)      zero-profit
       buba(h)     budget balance
       mcl(k)      market clearing
       plevel      fixing the price level ;

  cost(f) ..    c(f)**(1-sigma(f)) =e= sum(i,alpha(i,f)*p(i)**(1-sigma(f))) ;
  reve(f) ..    r(f)**(1+eta(f)) =e= sum(i,beta(i,f)*p(i)**(1+eta(f))) ;
  cpi(h) ..     pi(h)**(1-mu(h)) =e= sum(i,gamma(i,h)*p(i)**(1-mu(h))) ;
  zpr(f) ..     c(f) =e= r(f) ;
  buba(h) ..    u(h)*pi(h) =e= sum(i,p(i)*End(i,h)) ;
  mcl(k) ..     sum(f,x(f)*(beta(k,f)*(p(k)/r(f))**eta(f)-alpha(k,f)*(p(k)/c(f))**(-sigma(f))))
                       =e= sum(h,u(h)*gamma(k,h)*((p(k)/pi(h))**(-mu(h)))-End(k,h)) ;
  plevel ..     sum(h,pi(h)) =e= sum((i,h), Pay(i,h)) ;

  Model algebraic /all/ ;

* replicate benchmark: defines starting values for solution algorithm

c.l(f)    = sum(i,Pay(i,f));
r.l(f)    = sum(i,Rec(i,f));
pi.l(h)   = sum(i,Pay(i,h));
x.l(f)    = 1;
u.l(h)    = 1;
p.l(i)    = 1;

*  display p.l, x.l, u.l, pi.l, r.l, c.l, alpha, beta, gamma ;

  Solve algebraic using mcp ;

  display p.l, x.l, u.l, pi.l, r.l, c.l, alpha, beta, gamma ;


  End('Labour','Consumer')=shock*End('Labour','Consumer') ;
  Solve algebraic using mcp ;
  display p.l, x.l, u.l, pi.l, r.l, c.l, alpha, beta, gamma ;


*  End('Labour','Consumer')=1/shock*End('Labour','Consumer') ;
*  End('Capital','Consumer')=shock*End('Labour','Consumer') ;
*  Solve algebraic using mcp ;
*  display p.l, x.l, u.l, pi.l, r.l, c.l, alpha, beta, gamma ;
